@@ -7,7 +7,7 @@ def test():
     isNorm = True
     for i in m:
         i = int(i)
-        e, d, n = my_RSA.RSA.get_bit_keys(256)
+        e, d, n = my_RSA.RSA.get_bit_keys(256) #****************************************
         if (pow(pow(i, e, n), d, n)) != i:
             print("error")
             isNorm = False
